@@ -137,6 +137,10 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
                 )
 
                 if hasattr(response, "url"):
+                    if vulnerability_management.config_tool.get("VULNERABILITY_MANAGER").get("DEFECT_DOJO").get("PRINT_DOMAIN"):
+                        response.url = response.url.replace(vulnerability_management.config_tool["VULNERABILITY_MANAGER"][
+                            "DEFECT_DOJO"]["HOST_DEFECT_DOJO"
+                        ], vulnerability_management.config_tool["VULNERABILITY_MANAGER"]["DEFECT_DOJO"]["PRINT_DOMAIN"])
                     url_parts = response.url.split("//")
                     test_string = "//".join([url_parts[0] + "/", url_parts[1]])
                     print(
@@ -457,6 +461,7 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
         use_cmdb: bool,
     ):
         tool_scm_conf_mapping = vulnerability_management.config_tool["VULNERABILITY_MANAGER"]["DEFECT_DOJO"]["TOOL_SCM_MAPPING"]
+        tool_sonar_conf_mapping = vulnerability_management.config_tool["VULNERABILITY_MANAGER"]["DEFECT_DOJO"]["TOOL_SONAR_MAPPING"]
         common_fields = {
             "scan_type": self.scan_type_mapping[vulnerability_management.scan_type],
             "file": vulnerability_management.input_core.path_file_results,
@@ -495,6 +500,15 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
             "reimport_scan": vulnerability_management.config_tool[
                 "VULNERABILITY_MANAGER"
             ]["DEFECT_DOJO"]["REIMPORT_SCAN"],
+            "tool_sonarqube_configuration": (
+                tool_sonar_conf_mapping[
+                    vulnerability_management.sonar_instance.upper()
+                ]
+                if vulnerability_management.sonar_instance is not None
+                and vulnerability_management.sonar_instance.upper()
+                in tool_sonar_conf_mapping
+                else tool_sonar_conf_mapping["DEFAULT"]
+            ),
         }
 
         if use_cmdb:
